==> tenant-domain-1.0.45-20200316.050223-1-sources.jar: com/xforceplus/domain/settle/SettleTemplateAttributeDto.java <==
package com.xforceplus.domain.settle;


import java.util.Objects;

public class SettleTemplateAttributeDto {
    protected Long attributeId;
    protected Long templateId;
    protected String attributeName;
    protected Boolean enabled;
    protected Boolean readonly;
    protected Boolean required;
    protected Boolean unique;

    public Long getAttributeId() {
        return attributeId;
    }

    public void setAttributeId(Long attributeId) {
        this.attributeId = attributeId;
    }

    public Long getTemplateId() {
        return templateId;
    }

    public void setTemplateId(Long templateId) {
        this.templateId = templateId;
    }

    public String getAttributeName() {
        return attributeName;
    }

    public void setAttributeName(String attributeName) {
        this.attributeName = attributeName;
    }

    public Boolean getEnabled() {
        return enabled;
    }

    public void setEnabled(Boolean enabled) {
        this.enabled = enabled;
    }

    public Boolean getReadonly() {
        return readonly;
    }

    public void setReadonly(Boolean readonly) {
        this.readonly = readonly;
    }

    public Boolean getRequired() {
        return required;
    }

    public void setRequired(Boolean required) {
        this.required = required;
    }

    public Boolean getUnique() {
        return unique;
    }

    public void setUnique(Boolean unique) {
        this.unique = unique;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SettleTemplateAttributeDto that = (SettleTemplateAttributeDto) o;
        return Objects.equals(this.attributeId,  that.attributeId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(attributeId);
    }
}

==> tenant-domain-1.2.0-20200528.035948-2-sources.jar: com/xforceplus/domain/settle/SettleTemplateAttributeDto.java <==
package com.xforceplus.domain.settle;


import java.util.Objects;

public class SettleTemplateAttributeDto {
    protected Long attributeId;
    protected Long templateId;
    protected String attributeCode;
    protected String attributeName;
    protected Boolean enabled;
    protected Boolean readonly;
    protected Boolean required;
    protected Boolean unique;
    protected String expect;
    protected String pattern;


    public Long getAttributeId() {
        return attributeId;
    }

    public void setAttributeId(Long attributeId) {
        this.attributeId = attributeId;
    }

    public Long getTemplateId() {
        return templateId;
    }

    public void setTemplateId(Long templateId) {
        this.templateId = templateId;
    }

    public String getAttributeCode() {
        return attributeCode;
    }

    public void setAttributeCode(String attributeCode) {
        this.attributeCode = attributeCode;
    }

    public String getAttributeName() {
        return attributeName;
    }

    public void setAttributeName(String attributeName) {
        this.attributeName = attributeName;
    }

    public Boolean getEnabled() {
        return enabled;
    }

    public void setEnabled(Boolean enabled) {
        this.enabled = enabled;
    }

    public Boolean getReadonly() {
        return readonly;
    }

    public void setReadonly(Boolean readonly) {
        this.readonly = readonly;
    }

    public Boolean getRequired() {
        return required;
    }

    public void setRequired(Boolean required) {
        this.required = required;
    }

    public Boolean getUnique() {
        return unique;
    }

    public void setUnique(Boolean unique) {
        this.unique = unique;
    }

    public String getExpect() {
        return expect;
    }

    public void setExpect(String expect) {
        this.expect = expect;
    }

    public String getPattern() {
        return pattern;
    }

    public void setPattern(String pattern) {
        this.pattern = pattern;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SettleTemplateAttributeDto that = (SettleTemplateAttributeDto) o;
        return Objects.equals(this.attributeId, that.attributeId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(attributeId);
    }
}
